/* $Id: ProcessWaitActivityBean.java,v 1.1 2007/10/29 02:55:36 nito Exp $
 *
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow Core.
 * 
 *  Nautica Workflow Core is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow Core is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Nautica Workflow Core; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.workflow.dataaccess;

import java.io.Serializable;

/**
 * このクラスは、プロセス完了待ちアクティビティテーブル(PROCESS_WAIT_ACTIVITY)に対応する情報を保持する。
 *
 * @version	$Revision: 1.1 $, $Date: 2007/10/29 02:55:36 $
 * @since	Nautica Workflow 1.0
 */
public class ProcessWaitActivityBean implements Serializable
{
	/** シリアルバージョンUID */
	private static final long serialVersionUID = 20050000000000001L;

	/**
	 * プロセスインスタンスID
	 */
	protected String procID;

	/**
	 * 完了待ちアクティビティインスタンスID
	 */
	protected String actID;

	/**
	 * サブプロセスインスタンスID
	 */
	protected String subprocID;

	/**
	 * プロセス完了待ちアクティビティオブジェクトを生成する。
	 */
	public ProcessWaitActivityBean()
	{
	}

	/**
	 * プロセスインスタンスIDを取得する。
	 *
	 * @return	プロセスインスタンスID
	 */
	public String getProcID()
	{
		if (procID == null) return "";
		else return procID;
	}
	
	/**
	 * プロセスインスタンスIDを設定する。
	 *
	 * @param	procID	プロセスインスタンスID
	 */
	public void setProcID(String procID)
	{
		this.procID = procID;
	}

	/**
	 * 完了待ちアクティビティインスタンスIDを取得する。
	 *
	 * @return	完了待ちアクティビティインスタンスID
	 */
	public String getActID()
	{
		if (actID == null) return "";
		else return actID;
	}
	
	/**
	 * 完了待ちアクティビティインスタンスIDを設定する。
	 *
	 * @param	actID	完了待ちアクティビティインスタンスID
	 */
	public void setActID(String actID)
	{
		this.actID = actID;
	}

	/**
	 * サブプロセスインスタンスIDを取得する。
	 *
	 * @return	サブプロセスインスタンスID
	 */
	public String getSubprocID()
	{
		if (subprocID == null) return "";
		else return subprocID;
	}
	
	/**
	 * サブプロセスインスタンスIDを設定する。
	 *
	 * @param	subprocID	サブプロセスインスタンスID
	 */
	public void setSubprocID(String subprocID)
	{
		this.subprocID = subprocID;
	}

	/**
	 * ガーベジコレクタによる当該オブジェクトの解放処理を行う。
	 *
	 * @throws	Throwable	任意の例外
	 */
	protected void finalize() throws Throwable
	{
		// ここに独自の解放処理を実装する。
		super.finalize();
	}
	
	/**
	 * 引数のオブジェクトとの比較を行い、同一性を判定する。
	 *
	 * @param	obj	比較するオブジェクト
	 * @return	判定結果
	 */
	public boolean equals(Object obj)
	{
		boolean b = super.equals(obj);
		return b;
	}
}

